@@ -38,6 +38,7 @@
 #include "plugin.h"
 #include "plugin.moc"
 
+#include "recoveryinterface.h"
 #include "commandinterface.h"
 #include "markinterface.h"
 #include "modificationinterface.h"
@@ -142,10 +143,16 @@ bool View::insertText (const QString &text )
   return doc->insertText(cursorPosition(),text,blockSelection());
 }
 
+#ifndef KDE_NO_DEPRECATED
 Plugin *KTextEditor::createPlugin ( KService::Ptr service, QObject *parent )
 {
-  return service->createInstance<KTextEditor::Plugin>(parent);
+  QString error;
+  Plugin* plugin = service->createInstance<KTextEditor::Plugin>(parent, QVariantList(), &error);
+  if (!plugin)
+    kWarning() << error;
+  return plugin;
 }
+#endif
 
 struct KTextEditorFactorySet : public QSet<KPluginFactory*>
 {
@@ -300,6 +307,13 @@ ModeInterface::ModeInterface() {
 ModeInterface::~ModeInterface() {
 }
 
+RecoveryInterface::RecoveryInterface()
+  : d(0) {
+}
+
+RecoveryInterface::~RecoveryInterface() {
+}
+
 
 // kate: space-indent on; indent-width 2; replace-tabs on;
 
